<?php

/** Class Base Event for all Expay events */
abstract class ExpayBaseEvent {
  protected $order;
  protected $provider;

  /**
   * ExpayBaseEvent constructor.
   * @param StdClass $order
   * @param ExpayProvider $provider
   */
  public function __construct($order, $provider) {
    $this->order = $order;
    $this->provider = $provider;
  }

  public abstract function handle($event);

  protected function sendResponse($code, $message) {
    $response = [
      'response' => [
        'status' => $code,
        'message' => $message,
        'timestamp' => time()
      ]
    ];
    $response['hash'] = $this->provider->hashResponse(json_encode($response['response']));

    header('Content-type: application/json');
    print json_encode($response);
    drupal_exit();
  }

  protected function isOrderValid($event) {
    if (!($isInvalid = isset($this->order))) {
      watchdog('EPS Webhooks',  'the order#' . $event['data']['merchantOrder'] . 'doesn\'t exist', null, WATCHDOG_ALERT);
    }
    return $isInvalid;
  }

  protected function isOrderCanceled() {
    if ($isCanceled = ($this->order->status === 'canceled')) {
      watchdog('EPS Webhooks', 'the order#' . $this->order->order_id . ' has already been canceled', null, WATCHDOG_ALERT);
    }
    return $isCanceled;
  }

  protected function isOrderPaid() {
    $transaction = array_shift(commerce_payment_transaction_load_multiple([], ['order_id' => $this->order->order_id]));
    return $transaction->status === 'success';
  }

  protected function isHashValid($event) {
    if (!isset($event['hash'])) {
      watchdog('EPS Webhooks', 'invalid hash', null, WATCHDOG_ALERT);
      return false;
    }

    $hash = $event['hash'];
    unset($event['hash']);
    $hash2 = $this->provider->hashResponse(http_build_query($event, null, '&', PHP_QUERY_RFC3986));
    if ($hash !== $hash2) {
        watchdog('EPS Webhooks', 'invalid hash', null, WATCHDOG_ALERT);
      return false;
    }
    return true;
  }

  protected function amountMatching($event) {
    $transaction = array_shift(commerce_payment_transaction_load_multiple([], ['order_id' => $this->order->order_id]));
    // formatting of amount from merchant side (drupal stores it as integer value, request's amount is float value)
    $amount = sprintf("%.2f", $transaction->amount / 100);
    if ($amountNotMatches = ($amount !== $event['amount'])) {
      watchdog('EPS Webhooks', 'The amount of order#' . $this->order->id . " doesn't match.", null, WATCHDOG_ALERT);
    }
    return !$amountNotMatches;
  }
}
