<?php

class ExpayEventPay extends ExpayBaseEvent {
  public function handle($event) {
    if (!$this->isHashValid($event)) {
      $this->sendResponse(401, 'Invalid hash');
      return false;
    }

    if (!$this->isOrderValid($event) || !$this->amountMatching($event) || $this->isOrderCanceled()) {
      $this->sendResponse(475, 'Payment with the specified parameters can not be processed');
      return false;
    }

    if (!$this->isPaymentStatusSuccess($event)) {
      watchdog('EPS Webhooks', 'status of order#' . $this->order->order_id . ' change to "Canceled"', null, WATCHDOG_INFO);

      // change status of transaction to 'failure'
      $transaction = array_shift(commerce_payment_transaction_load_multiple([], ['order_id' => $this->order->order_id]));
      $transaction->status = COMMERCE_PAYMENT_STATUS_FAILURE;
      commerce_payment_transaction_save($transaction);

      $this->sendResponse(475, 'Payment with the specified parameters can not be processed');
      return false;
    }

    if ($this->isOrderPaid()) {
      $this->sendResponse(205, 'Payment success');
      return true;
    }

    // change status of transaction to 'success'
    $transaction = array_shift(commerce_payment_transaction_load_multiple([], ['order_id' => $this->order->order_id]));
    $transaction->status = COMMERCE_PAYMENT_STATUS_SUCCESS;
    commerce_payment_transaction_save($transaction);

    watchdog('EPS Webhooks', 'status of order#' . $this->order->order_id . ' change to "Payment accepted"', null, WATCHDOG_INFO);
    $this->sendResponse(205, 'Payment success');

    return true;
  }

  private function isPaymentStatusSuccess($event) {
    $status = $this->provider->getPaymentStatus($event['id']);
    if ($status != 203 && $status != 205) {
      watchdog(
        'EPS Webhooks',
        'The status of order #' . $this->order->order_id . ' in EPS API is not success.',
        null,
        WATCHDOG_INFO
      );
      return false;
    }
    return true;
  }
}
