<?php
/**
 * @file
 * Commerce Expay Payment Admin Settings.
 */

/**
 * Returns the default settings for the EXPAY payment method.
 */
function commerce_expay_default_settings()
{
  return [
    'test' => [
      'private_key' => '',
      'public_key' => '',
    ],
    'live' => [
      'private_key' => '',
      'public_key' => '',
    ],
  ];
}

/**
 * Payment method callback: Generates the payment method settings form.
 */
function commerce_expay_settings_form($settings = null) {
  $form = [];
  $settings = (array)$settings + [
      'public_key' => '',
      'private_key' => '',
      'live_link' => 'https://api.elementpay.io/merchant/',
      'sandbox_link' => 'https://api-sbox.elementpay.io/merchant/'
    ];
  $form['live_link'] = [
    '#type' => 'textfield',
    '#title' => t('Live link'),
    '#description' => t('live link to API'),
    '#default_value' => $settings['live_link'],
    '#required' => true,
  ];
  $form['sandbox_link'] = [
    '#type' => 'textfield',
    '#title' => t('Sandbox link'),
    '#description' => t('Sandbox link to API'),
    '#default_value' => $settings['sandbox_link'],
    '#required' => true,
  ];
  $form['private_key'] = [
    '#type' => 'textfield',
    '#title' => t('Merchant secret'),
    '#description' => t('Private key'),
    '#default_value' => $settings['private_key'],
    '#required' => true,
  ];
  $form['public_key'] = [
    '#type' => 'textfield',
    '#title' => t('Merchant key'),
    '#description' => t('Public key'),
    '#default_value' => $settings['public_key'],
    '#required' => true,
  ];
  $form['mode'] = [
    '#type' => 'radios',
    '#title' => t('Mode'),
    '#options' => [
      'live' => t('Live'),
      'test' => t('Test'),
    ],
    '#default_value' => 'live',
    '#required' => true,
  ];
  $form['implementation'] = [
    '#type' => 'radios',
    '#title' => t('Implementation'),
    '#options' => [
      'light_api' => t('Light API'),
      'full' => t('Full integration'),
    ],
    '#default_value' => 'light_api',
    '#required' => true,
  ];
  $form['ipn'] = ['#markup' =>  '<b> EPS Webhook: </b>' . '<mark>' . t(commerce_expay_ipn_url()) . '</mark>'];

  $form['#submit'][] = 'commerce_expay_settings_submit_form';
  return $form;
}

/**
 * Payment method callback: submit form validation.
 */
function commerce_expay_settings_submit_form($form, $form_state) {
  // Return an error if settings haven't been configured.
  if (empty($form['public_key'] || empty($form['private_key']))) {
    drupal_set_message(t('EPS payment module is not configured for use. Please contact an administrator to resolve this issue.'), 'error');
    return FALSE;
  }

  return TRUE;
}

/**
 * Returns the IPN URL.
 *
 * @param null $instance_id
 * @return string
 */
function commerce_expay_ipn_url($instance_id = null)
{
  $parts = array(
    'commerce_expay',
    'ipn',
  );

  if (!empty($instance_id)) {
    $parts[] = $instance_id;
  }

  return url(implode('/', $parts), array('absolute' => true));
}
